# Buckets Adapter

Buckets Adapter Django module is a base for upload files on bucket for different web services e.g Google Cloud Platform or Amazon Web Services which will be used as a package in different projects.

## Building docs

To build sphinx documentation for this module, follow these steps.

### Pre-requisite

1. Install sphinx module using the following command:

    ```bash
    pip install sphinx
    ```

2. Make sure you have gcc insalled for running **make** files.

### Creating HTML document

Follow these steps the create HTML related document:

1. Change your working directory to **docs/**

2. Run the following command:

    ```bash
    make html
    ```
